@@ -1,4 +1,4 @@
-/* $Id: acconfig.h,v 1.10 1997/01/07 20:05:31 wessels Exp $ */
+/* $Id: acconfig.h,v 1.10.2.1 1997/03/03 03:41:34 wessels Exp $ */
 
 /* Define if struct tm has tm_gmtoff member */
 #undef HAVE_TM_GMTOFF
@@ -6,6 +6,9 @@
 /* Define if struct mallinfo has mxfast member */
 #undef HAVE_EXT_MALLINFO
 
+/* Default FD_SETSIZE value */
+#undef DEFAULT_FD_SETSIZE
+
 /* Maximum number of open filedescriptors */
 #undef SQUID_MAXFD
 
